@@ -198,9 +198,18 @@ def gen_class_h(bdir, data):
 			write_line(f)
 			cn += 1
 	
+	write_define(f, 'ACLASS_Int', 'CLASS_IArray', 32)
+	write_define(f, 'ATYPE_Int', 'CLASS_IArray', 32)
+	write_define(f, 'NNATYPE_Int', 'NNTYPE_cid(CLASS_IArray)', 32)
+	
+	write_define(f, 'ACLASS_Float', 'CLASS_FArray', 32)
+	write_define(f, 'ATYPE_Float', 'CLASS_FArray', 32)
+	write_define(f, 'NNATYPE_Float', 'NNTYPE_cid(CLASS_FArray)', 32)
+	
 	write_chapter(f, '[Array<X>]')
 	for cname in data.ACLASS_LIST:
 		cname = cname.replace(":", "__")
+		if cname == 'Int' or cname == 'Float': continue
 		write_define(f, 'ACLASS_%s' % cname, '((knh_class_t)(KNH_TSTRUCT_SIZE+%d))' % cn, 32)
 		write_define(f, 'ATYPE_%s' % cname, 'ACLASS_%s' % cname, 32)
 		write_define(f, 'NNATYPE_%s' % cname, 'NNTYPE_cid(ACLASS_%s)' % cname, 32)
@@ -214,6 +223,13 @@ def gen_class_h(bdir, data):
 		write_define(f, 'NNITYPE_%s' % cname, 'NNTYPE_cid(ICLASS_%s)' % cname, 32)
 		cn += 1
 	
+	write_chapter(f, '[Generics]')
+	for c in data.GENERICS_LIST:
+		write_define(f, 'CLASS_%s' % c.cname, '((knh_class_t)(KNH_TSTRUCT_SIZE+%d))' % cn, 32)
+		write_define(f, 'TYPE_%s' % c.cname, 'CLASS_%s' % c.cname, 32)
+		write_define(f, 'NNTYPE_%s' % c.cname, 'NNTYPE_cid(CLASS_%s)' % cname, 32)
+		cn += 1
+		
 	write_chapter(f, '[Object:X]')
 	for cname in data.XCLASS_LIST:
 		cname = cname.replace(":", "__")
@@ -580,9 +596,12 @@ def write_structdata_c(f, c, data):
 	f.write(fmt % (c.cname, size))
 
 def write_classdata_c(f, c, data):
+	fullname = c.fullname
+	if c.cname == 'IArray': fullname = 'Int[]'
+	if c.cname == 'FArray': fullname = 'Float[]'
 	fmt = '''
 \t{"%s", CLASS_$C, CFLAG_$C, %s, %s, 0, %d, 0, knh_$C_fdefault},'''.replace('$C', c.cname)
-	f.write(fmt % (c.fullname, STRUCT_cname(c.cname), CLASS_cname(c.super_cname), c.method_size))
+	f.write(fmt % (fullname, STRUCT_cname(c.cname), CLASS_cname(c.super_cname), c.method_size))
 	
 
 def write_methoddata_c(f, mtd, data):
@@ -658,6 +677,21 @@ static knh_GenericsData_t GenericsData[] = {''')
 		cname = cname.replace(":", "__")
 		f.write('''
 \t{"%s..", ICLASS_%s, CLASS_Iterator, CLASS_%s, CLASS_Nue},''' % (cname, cname, cname))
+	for c in data.GENERICS_LIST:
+		if c.bname == 'Closure': continue
+		f.write('''
+\t{"%s", CLASS_%s, CLASS_%s, CLASS_%s, CLASS_%s},''' % (c.fullname, c.cname, c.bname, c.params[0], c.params[1]))
+	f.write('''
+	{NULL}
+};
+''')
+
+	f.write('''
+static knh_ClosureData_t ClosureData[] = {''')
+	for c in data.GENERICS_LIST:
+		if c.bname != 'Closure': continue
+		f.write('''
+\t{"%s", CLASS_%s, %s, %s, %s, %s},''' % (c.fullname, c.cname, TYPE_cname(c.params[0]), TYPE_cname(c.params[1]), TYPE_cname(c.params[2]), TYPE_cname(c.params[3])))
 	f.write('''
 	{NULL}
 };
