@@ -38,7 +38,7 @@ extends @token
 implements CLASSN*:class[] @stmt @token
 
 method TYPEN:rtype cmethod.. CLASSN:class METHODN:method STT_DECL:params {:instmt  @stmt  @token @name @cmpl
-closure TYPEN:rtype STT_DECL:params {:instmt @stmt 
+function TYPEN:rtype STT_DECL:params {:instmt @stmt @token
 
 format MT:name PARAM*:params STR:format ;   @stmt  @token @new @name @cmpl
 decl TYPEN:type VARN:name expr:value @stmt @name
@@ -83,7 +83,6 @@ letmulti VARN*:names[]               @stmt
 @expr pcall   METHODN:method expr:base pcall.. expr*:args[] @stmt
 @expr mt      MT:mt expr:target expr:option @stmt  @cmpl
 @expr op      expr:first expr:second expr*:args[] @stmt  @cmpl
-@expr invoke  expr:func expr*args[] @stmt @cmpl
 @expr proceed METHODN:method expr:base expr*args[]
 
 @expr tri     expr:bool expr:tvalue expr:fvalue @stmt  @cmpl
@@ -106,6 +105,7 @@ TOKEN = '''
 
 ; SEMICOLON      @stmt     @eos
 , COMMA          @P0
+=> FUNCMAP       @P99
 = LET            @P0
 <<= lshifte      
 >>= rshifte       
@@ -162,8 +162,8 @@ to? To                 @op @A2  @P9
 * Mul                  @op @2    @P24  @A2
 
 & Land                 @op @top      @P27
-~ Lnot                 @op @A1 @top   @P27
-^ Xor                  @op @A2 @top    @P27
+~ Lnot                 @op @A1 @top  @P27
+^ Xor                  @op @A2 @top  @P27
 ++ Next                @op @A1 @top  @P28
 -- Prev                @op @A1 @top  @P28
 --- Neg                @op @A1 @top  @P28
@@ -235,7 +235,6 @@ False   false           @alias
 
 #------------------------------------------------------------------------------
 
-
 class Token:
     def __init__(self, line):
         self.line = line
