@@ -77,7 +77,7 @@ typedef struct knh_ObjectField_t {
 /* @class Any3 Any knh_Any_t @Cyclic  @Private */
 
 struct knh_Glue_t;
-typedef void (*knh_fgfree)(Ctx *, struct knh_Glue_t *o, knh_ftraverse ftr);
+typedef void (*knh_fgfree)(Ctx *, struct knh_Glue_t *o);
 
 typedef struct knh_Glue_t {
 	knh_hObject_t h;
