@@ -149,13 +149,6 @@ extern "C" {
 #define TERMs_getbcid(stmt, n)   ctx->tClass[TERMs_getcid(stmt,n)].bcid
 #define KNH_OUTERPARAMS -1
 #define KNH_INNERPARAMS -2
-#define KNH_SYS(ctx, n)    knh_tConst_systemValue(ctx, n)
-#define KNH_SYS_CTX    0
-#define KNH_SYS_STDIN  1
-#define KNH_SYS_STDOUT 2
-#define KNH_SYS_STDERR 3
-#define KNH_SYS_OS     4
-#define KNH_SYS_SCRIPT 5
 #define knh_tMapper_find(ctx, scid, tcid) knh_tMapper_find_(ctx, scid, tcid, 1)
 #define knh_Class_getMapper(ctx, scid, tcid)  knh_tMapper_find_(ctx, scid, tcid, 0)
 #define knh_tMethodField_size               knh_Array_size(DP(ctx->sys)->tMethodFields)
@@ -179,8 +172,15 @@ extern "C" {
 
 
 #define TODO_THROW(ctx) knh_throw_TODO(ctx, (char*)__FILE__, __LINE__, (char*)__FUNCTION__)
-#define FIELDN(fn) knh_String_tochar(knh_tfieldn_name(ctx, fn))
-#define FILEIDN(fileid) knh_String_tochar(knh_tfileid_name(ctx, fileid))
+#define KNH_SYS(ctx, n)    konoha_getSystemConst(ctx, n)
+#define KNH_SYS_CTX    0
+#define KNH_SYS_STDIN  1
+#define KNH_SYS_STDOUT 2
+#define KNH_SYS_STDERR 3
+#define KNH_SYS_OS     4
+#define KNH_SYS_SCRIPT 5
+#define FIELDN(fn) knh_String_tochar(konoha_getFieldName(ctx, fn))
+#define FILEIDN(fileid) knh_String_tochar(konoha_getFileName(ctx, fileid))
 
 /* ======================================================================== */
 /* [PROTOTYPE] */
@@ -219,6 +219,8 @@ KNHAPI(ClassSpec*) new_Unit(Ctx *ctx, char *tag, knh_float_t min, knh_float_t ma
 KNHAPI(InputStream*) new_FileInputStream(Ctx *ctx, knh_bytes_t file);
 KNHAPI(InputStream*) new_BytesInputStream(Ctx *ctx, Bytes *ba, size_t s, size_t e);
 KNHAPI(InputStream*) new_StringInputStream(Ctx *ctx, String *str, size_t s, size_t e);
+KNHAPI(void) knh_Glue_init(Ctx *ctx, knh_Glue_t *g, void *ptr, knh_fgfree gfree);
+KNHAPI(Object*) new_Glue(Ctx *ctx, char *lname, void *ptr, knh_fgfree gfree);
 KNHAPI(OutputStream*) new_FileOutputStream(Ctx *ctx, knh_bytes_t file, char *mode);
 KNHAPI(OutputStream*) new_BytesOutputStream(Ctx *ctx, Bytes *ba);
 KNHAPI(void) knh_putc(Ctx *ctx, OutputStream *w, int ch);
@@ -250,9 +252,8 @@ KNHAPI(void) konoha_addVocabularyMapper(Ctx *ctx, knh_class_t scid, char *text);
 KNHAPI(void) konoha_addDBDriver(Ctx *ctx, char *alias, knh_db_drvapi_t *d);
 KNHAPI(void) konoha_addIODriver(Ctx *ctx, char *alias, knh_iodrv_t *d);
 KNHAPI(void) konoha_addRegexDriver(Ctx *ctx, char *alias, knh_regex_drvapi_t *d);
-KNHAPI(int) knh_System_hasLibrary(Ctx *ctx, char *libname, char *funcname);
-KNHAPI(void) konoha_addClassSpecFunc(Ctx *ctx, char *urn, f_makespec func);
 KNHAPI(Ctx*) konoha_getCurrentContext(void);
+KNHAPI(int) konoha_isDebugMode();
 KNHAPI(int) konoha_parseopt(konoha_t konoha, int argc, char **argv);
 KNHAPI(char*) konoha_eval(konoha_t konoha, char *script);
 KNHAPI(void) konoha_readFile(Ctx *ctx, char *fpath);
@@ -262,18 +263,6 @@ KNHAPI(void) konoha_shell(konoha_t konoha);
 KNHAPI(char*) knh_format_ospath(Ctx *ctx, char *buf, size_t bufsiz, knh_bytes_t path);
 KNHAPI(void) konoha_SETv(Ctx *ctx, Object **v, Object *o);
 KNHAPI(void) konoha_FINALv(Ctx *ctx, Object **v);
-KNHAPI(knh_class_t) konoha_addClass(Ctx *ctx, knh_flag_t flag, char *name, int method_size);
-KNHAPI(knh_class_t) konoha_addVirtualClass(Ctx *ctx, char *name, int method_size);
-KNHAPI(knh_class_t) konoha_addNaitiveClass(Ctx *ctx, char *name, int method_size);
-KNHAPI(void) konoha_addDefaultObject(Ctx *ctx, Object *o);
-KNHAPI(void) konoha_addMethod(Ctx *ctx, char *kscript, knh_fmethod f);
-KNHAPI(void) konoha_addFormatter(Ctx *ctx, char *cname, char *fmt, void *f);
-KNHAPI(void) konoha_addConst(Ctx *ctx, char *name, Object *o);
-KNHAPI(void) konoha_addIntConst(Ctx *ctx, char *name, knh_int_t value);
-KNHAPI(void) konoha_addIntegerConst(Ctx *ctx, char *name, knh_integer_t value);
-KNHAPI(void) konoha_addFloatConst(Ctx *ctx, char *name, knh_float_t value);
-KNHAPI(void) konoha_addStringConst(Ctx *ctx, char *name, char *text);
-KNHAPI(void) konoha_addDriver(Ctx *ctx, char *name, int type, void *drv);
 KNHAPI(char*) KNH_SAFEFILE(char *file);
 KNHAPI_(Object*) knh_boxing(Ctx *ctx, knh_sfp_t *sfp, knh_class_t cid);
 KNHAPI_(void) knh_sfp_boxing(Ctx *ctx, knh_sfp_t *sfp);
@@ -281,11 +270,14 @@ KNHAPI_(void) knh_sfp_unboxing(Ctx *ctx, knh_sfp_t *sfp);
 KNHAPI(void) knh_sfp_sformat(Ctx *ctx, knh_sfp_t *lsfp, Method *mtd, OutputStream *w, Any *m);
 KNHAPI(void) knh_sfp_format(Ctx *ctx, knh_sfp_t *sfp, knh_methodn_t mn, OutputStream *w, Any *m);
 KNHAPI(void) knh_throw_TODO(Ctx *ctx, char *file, int line, char *func);
-KNHAPI(char*) konoha_doing(Ctx *ctx, char *msg);
 KNHAPI(void) knh_throwException(Ctx *ctx, Exception *e, char *file, int line);
 KNHAPI(void) knh_throw__s(Ctx *ctx, char *msg, char *file, int line);
 KNHAPI(void) knh_throw(Ctx *ctx, Object *e, char *file, int line);
 KNHAPI(void) konoha_throwSecurityException(void);
+KNHAPI(void) konoha_loadIntConstData(Ctx *ctx, knh_IntConstData_t *data);
+KNHAPI(void) konoha_loadFloatConstData(Ctx *ctx, knh_FloatConstData_t *data);
+KNHAPI(void) konoha_loadStringConstData(Ctx *ctx, knh_StringConstData_t *data);
+KNHAPI(void) konoha_addClassSpecFunc(Ctx *ctx, char *urn, knh_fspec func);
 KNHAPI(konoha_t) konoha_open(size_t ctxsize, size_t stacksize);
 KNHAPI(void) konoha_close(konoha_t konoha);
 
