@@ -48,11 +48,11 @@ extern "C" {
 #define knh_Object_RCinc(o)     (o)->h.refc = (KNH_RCGC_MASK & ((o)->h.refc + 1))
 #define knh_Object_RCplus(o,n)  (o)->h.refc = (KNH_RCGC_MASK & ((o)->h.refc + n))
 #define knh_Object_DRCsweep(ctx, o)  knh_Object_RCdec(o)
-//#define knh_Object_DRCsweep(ctx, o)  knh_Object_RCsweep(ctx, o)
+//#define knh_Object_DRCsweep(ctx, o)  knh_Object_sweep(ctx, o)
 #else
 #define knh_Object_RCinc(o)     (o)->h.refc ++
 #define knh_Object_RCplus(o,n)  (o)->h.refc += n
-#define knh_Object_DRCsweep(ctx, o)  knh_Object_RCsweep(ctx, o)
+#define knh_Object_DRCsweep(ctx, o)  knh_Object_sweep(ctx, o)
 #endif
 #define knh_Object_RCdec(o)     (o)->h.refc--
 #define knh_Object_RCset(o,c)   (o)->h.refc = (c)
