@@ -36,65 +36,26 @@ extern "C" {
 #endif
 
 /* ======================================================================== */
-/* [new] */
+
+#ifdef KNH_CC_METHODAPI
 
 /* ------------------------------------------------------------------------ */
 /* @method InputStream InputStream.new(String! urn) */
 
-METHOD knh__InputStream_new(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__InputStream_new(Ctx *ctx, knh_sfp_t *sfp)
 {
 	InputStream *o = (InputStream*)sfp[0].o;
-//	knh_InputStream_setEncoding(ctx, o, sfp[2].s);
 	KNH_RETURN(ctx, sfp, knh_InputStream_open(ctx, o, sfp[1].s));
 }
 
-/* ------------------------------------------------------------------------ */
-/* @method void InputStream.setEncoding(String enc) */
-
-void knh_InputStream_setEncoding(Ctx *ctx, InputStream *o, String *enc)
-{
-	if(IS_NULL(enc)) {
-		KNH_SETv(ctx, DP(o)->enc, TS_ENCODING);
-		KNH_SETv(ctx, DP(o)->bconv, KNH_NULL);
-	}
-	else if(knh_bytes_strcasecmp(knh_String_tobytes(enc), STEXT(KONOHA_ENCODING)) == 0) {
-		KNH_SETv(ctx, DP(o)->enc, TS_ENCODING);
-		KNH_SETv(ctx, DP(o)->bconv, KNH_NULL);
-	}
-	else {
-		BytesConv *bin = new_BytesConv__in(ctx, knh_String_tochar(enc));
-		if(IS_NULL(bin)) {
-			KNH_SETv(ctx, DP(o)->enc, TS_ENCODING);
-			KNH_WARNING(ctx, "unsupported character encoding: %s", knh_String_tochar(enc));
-		}
-		else {
-			KNH_SETv(ctx, DP(o)->enc, enc);
-		}
-		KNH_SETv(ctx, DP(o)->bconv, bin);
-	}
-}
-
 /* ------------------------------------------------------------------------ */
 /* @method Boolean! InputStream.isClosed() */
 
-METHOD knh__InputStream_isClosed(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__InputStream_isClosed(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Boolean(ctx, sfp, knh_InputStream_isClosed((InputStream*)sfp[0].o));
 }
 
-/* ======================================================================== */
-/* [movabletext] */
-
-/* @method void InputStream.%dump(OutputStream w, String m) */
-
-void knh_InputStream__dump(Ctx *ctx, InputStream *b, OutputStream *w, String *m)
-{
-	TODO();
-}
-
-/* ------------------------------------------------------------------------ */
-/* ======================================================================== */
-/* [mapping] */
 
 /* ======================================================================== */
 /* [iterators] */
@@ -123,17 +84,15 @@ ITRNEXT knh_InputStream_line_next(Ctx *ctx, knh_sfp_t *sfp, int n)
 /* ------------------------------------------------------------------------ */
 /* @map InputStream String.. @Final */
 
-MAPPER knh_InputStream_String__(Ctx *ctx, knh_sfp_t *sfp)
+static MAPPER knh_InputStream_String__(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_MAPPED(ctx, sfp, new_Iterator(ctx, CLASS_String, sfp[0].o, knh_InputStream_line_next));
 }
 
-/* ======================================================================== */
-/* [movabletext] */
-
 /* ------------------------------------------------------------------------ */
 /* @method void InputStream.%k(OutputStream w, String m) */
 
+static
 void knh_InputStream__k(Ctx *ctx, InputStream *o, OutputStream *w, String *m)
 {
 	knh_putc(ctx, w, '\'');
@@ -142,24 +101,21 @@ void knh_InputStream__k(Ctx *ctx, InputStream *o, OutputStream *w, String *m)
 }
 
 /* ======================================================================== */
-/* [constructor] */
+/* [OutputStream] */
 
 /* @method OutputStream OutputStream.new(String! urn, String mode) */
 
-METHOD knh__OutputStream_new(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__OutputStream_new(Ctx *ctx, knh_sfp_t *sfp)
 {
 	OutputStream *o = (OutputStream*)sfp[0].o;
 	KNH_RETURN(ctx, sfp, knh_OutputStream_open(ctx, o, sfp[1].s, sfp[2].s));
 }
 
-/* ------------------------------------------------------------------------ */
-/* ======================================================================== */
-/* [method] */
 
 /* ------------------------------------------------------------------------ */
 /* @method void OutputStream.write(Bytes! buf, Int offset, Int len) */
 
-METHOD knh__OutputStream_write(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__OutputStream_write(Ctx *ctx, knh_sfp_t *sfp)
 {
 	OutputStream *o = (OutputStream*)sfp[0].o;
 	knh_bytes_t buf = knh_Bytes_tobytes((Bytes*)sfp[1].o);
@@ -174,41 +130,15 @@ METHOD knh__OutputStream_write(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method Boolean! OutputStream.isClosed() */
 
-METHOD knh__OutputStream_isClosed(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__OutputStream_isClosed(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Boolean(ctx, sfp, knh_OutputStream_isClosed((OutputStream*)sfp[0].o));
 }
 
-/* ------------------------------------------------------------------------ */
-/* @method void OutputStream.setEncoding(String enc) */
-
-void knh_OutputStream_setEncoding(Ctx *ctx, OutputStream *o, String *enc)
-{
-	if(IS_NULL(enc)) {
-		KNH_SETv(ctx, DP(o)->enc, TS_ENCODING);
-		KNH_SETv(ctx, DP(o)->bconv, KNH_NULL);
-	}
-	else if(knh_bytes_strcasecmp(knh_String_tobytes(enc), STEXT(KONOHA_ENCODING)) == 0) {
-		KNH_SETv(ctx, DP(o)->enc, TS_ENCODING);
-		KNH_SETv(ctx, DP(o)->bconv, KNH_NULL);
-	}
-	else {
-		BytesConv *bout = new_BytesConv__out(ctx, knh_String_tochar(enc));
-		if(IS_NULL(bout)) {
-			KNH_SETv(ctx, DP(o)->enc, TS_ENCODING);
-			KNH_WARNING(ctx, "unsupported character encoding: %s", knh_String_tochar(enc));
-		}
-		else {
-			KNH_SETv(ctx, DP(o)->enc, enc);
-		}
-		KNH_SETv(ctx, DP(o)->bconv, bout);
-	}
-}
-
 /* ------------------------------------------------------------------------ */
 /* @method void OutputStream.print(Any v) */
 
-METHOD knh__OutputStream_print(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__OutputStream_print(Ctx *ctx, knh_sfp_t *sfp)
 {
 	if(IS_bString(sfp[1].o)) {
 		knh_OutputStream_print_(ctx, sfp[0].w, knh_String_tobytes(sfp[1].s), 0);
@@ -222,7 +152,7 @@ METHOD knh__OutputStream_print(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method void OutputStream.println(Any v) */
 
-METHOD knh__OutputStream_println(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__OutputStream_println(Ctx *ctx, knh_sfp_t *sfp)
 {
 	if(IS_bString(sfp[1].o)) {
 		knh_OutputStream_print_(ctx, sfp[0].w, knh_String_tobytes(sfp[1].s), 1);
@@ -237,7 +167,7 @@ METHOD knh__OutputStream_println(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[VARARGS] void OutputStream.opLshift(Any v) */
 
-METHOD knh__OutputStream_opLshift(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__OutputStream_opLshift(Ctx *ctx, knh_sfp_t *sfp)
 {
 	OutputStream *out = (OutputStream*)sfp[0].o;
 	knh_sfp_t *v = sfp + 1;
@@ -268,10 +198,6 @@ METHOD knh__OutputStream_opLshift(Ctx *ctx, knh_sfp_t *sfp)
 	KNH_RETURN_void(ctx, sfp);
 }
 
-/* ------------------------------------------------------------------------ */
-/* ======================================================================== */
-/* [movabletext] */
-
 /* ------------------------------------------------------------------------ */
 /* @method void OutputStream.%k(OutputStream w, String m) */
 
@@ -282,7 +208,63 @@ void knh_OutputStream__k(Ctx *ctx, OutputStream *o, OutputStream *w, String *m)
 	knh_putc(ctx, w, '\'');
 }
 
+#else /*KNH_CC_METHODAPI*/
+
 /* ------------------------------------------------------------------------ */
+/* @method void InputStream.setEncoding(String enc) */
+
+void knh_InputStream_setEncoding(Ctx *ctx, InputStream *o, String *enc)
+{
+	if(IS_NULL(enc)) {
+		KNH_SETv(ctx, DP(o)->enc, TS_ENCODING);
+		KNH_SETv(ctx, DP(o)->bconv, KNH_NULL);
+	}
+	else if(knh_bytes_strcasecmp(knh_String_tobytes(enc), STEXT(KONOHA_ENCODING)) == 0) {
+		KNH_SETv(ctx, DP(o)->enc, TS_ENCODING);
+		KNH_SETv(ctx, DP(o)->bconv, KNH_NULL);
+	}
+	else {
+		BytesConv *bin = new_BytesConv__in(ctx, knh_String_tochar(enc));
+		if(IS_NULL(bin)) {
+			KNH_SETv(ctx, DP(o)->enc, TS_ENCODING);
+			KNH_WARNING(ctx, "unsupported character encoding: %s", knh_String_tochar(enc));
+		}
+		else {
+			KNH_SETv(ctx, DP(o)->enc, enc);
+		}
+		KNH_SETv(ctx, DP(o)->bconv, bin);
+	}
+}
+
+/* ------------------------------------------------------------------------ */
+/* @method void OutputStream.setEncoding(String enc) */
+
+void knh_OutputStream_setEncoding(Ctx *ctx, OutputStream *o, String *enc)
+{
+	if(IS_NULL(enc)) {
+		KNH_SETv(ctx, DP(o)->enc, TS_ENCODING);
+		KNH_SETv(ctx, DP(o)->bconv, KNH_NULL);
+	}
+	else if(knh_bytes_strcasecmp(knh_String_tobytes(enc), STEXT(KONOHA_ENCODING)) == 0) {
+		KNH_SETv(ctx, DP(o)->enc, TS_ENCODING);
+		KNH_SETv(ctx, DP(o)->bconv, KNH_NULL);
+	}
+	else {
+		BytesConv *bout = new_BytesConv__out(ctx, knh_String_tochar(enc));
+		if(IS_NULL(bout)) {
+			KNH_SETv(ctx, DP(o)->enc, TS_ENCODING);
+			KNH_WARNING(ctx, "unsupported character encoding: %s", knh_String_tochar(enc));
+		}
+		else {
+			KNH_SETv(ctx, DP(o)->enc, enc);
+		}
+		KNH_SETv(ctx, DP(o)->bconv, bout);
+	}
+}
+
+/* ------------------------------------------------------------------------ */
+
+#endif /*KNH_CC_METHODAPI*/
 
 /* ------------------------------------------------------------------------ */
 
