@@ -35,63 +35,48 @@
 extern "C" {
 #endif
 
-/* ======================================================================== */
-/* [constructor] */
+#ifdef KNH_CC_METHODAPI
 
-/* ======================================================================== */
-/* [method] */
+/* ------------------------------------------------------------------------ */
+/* @method[CONST] Boolean! String.equals(String! s) */
 
-/* @method Boolean! String.equals(String! s) */
-
-INLINE
-knh_bool_t knh_String_equals(String *o, knh_bytes_t s)
+static METHOD knh__String_equals(Ctx *ctx, knh_sfp_t *sfp)
 {
-//	knh_bytes_t t = knh_String_tobytes(o);
-	return (o->size == s.len && knh_strncmp((char*)o->str, (char*)s.buf, s.len) == 0);
+	KNH_RETURN_Boolean(ctx, sfp,
+		((sfp[0].s)->size == (sfp[1].s)->size &&
+		knh_bytes_strcmp(knh_String_tobytes(sfp[0].s), knh_String_tobytes(sfp[1].s))));
 }
 
 /* ------------------------------------------------------------------------ */
-/* @method Boolean! String.startsWith(String! s) */
+/* @method[CONST] Boolean! String.equalsIgnoreCase(String! s) */
 
-INLINE
-knh_bool_t knh_String_startsWith(String *b, knh_bytes_t s)
+static METHOD knh__String_equalsIgnoreCase(Ctx *ctx, knh_sfp_t *sfp)
 {
-	return knh_bytes_startsWith(knh_String_tobytes(b), s);
+	KNH_RETURN_Boolean(ctx, sfp,
+		((sfp[0].s)->size == (sfp[1].s)->size &&
+		knh_bytes_strcasecmp(knh_String_tobytes(sfp[0].s), knh_String_tobytes(sfp[1].s))));
 }
 
 /* ------------------------------------------------------------------------ */
-/* @method Boolean! String.endsWith(String! s) */
+/* @method[CONST] Boolean! String.startsWith(String! s) */
 
-INLINE
-knh_bool_t knh_String_endsWith(String *b, knh_bytes_t s)
+static METHOD knh__String_startsWith(Ctx *ctx, knh_sfp_t *sfp)
 {
-	return knh_bytes_endsWith(knh_String_tobytes(b), s);
+	KNH_RETURN_Boolean(ctx, sfp, knh_bytes_startsWith(knh_String_tobytes(sfp[0].s), knh_String_tobytes(sfp[1].s)));
 }
 
 /* ------------------------------------------------------------------------ */
+/* @method[CONST] Boolean! String.endsWith(String! s) */
 
-knh_index_t knh_bytes_indexOf(knh_bytes_t base, knh_bytes_t delim)
+static METHOD knh__String_endsWith(Ctx *ctx, knh_sfp_t *sfp)
 {
-	size_t i, j;
-	//TODO: handle, when delim is NULL. ""
-	if(delim.len > base.len) {
-		// Error. array index is out of boundary
-		return -1;
-	}
-	for (i = 0; i <= base.len - delim.len; i++) {
-		j = 0;
-		while ((j < delim.len) && (base.buf[i+j] == delim.buf[j])) {
-			j++;
-		}
-		if (j == delim.len) return i;
-	}
-	return -1;
+	KNH_RETURN_Boolean(ctx, sfp, knh_bytes_endsWith(knh_String_tobytes(sfp[0].s), knh_String_tobytes(sfp[1].s)));
 }
 
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] Int! String.indexOf(String! s) */
 
-METHOD knh__String_indexOf(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__String_indexOf(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_bytes_t base = knh_String_tobytes(sfp[0].s);
 	knh_bytes_t delim = knh_String_tobytes(sfp[1].s);
@@ -107,7 +92,7 @@ METHOD knh__String_indexOf(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST|NULLBASE] Int! String.opSize() */
 
-METHOD knh__String_opSize(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__String_opSize(Ctx *ctx, knh_sfp_t *sfp)
 {
 	if(IS_NULL(sfp[0].o)) {
 		KNH_RETURN_Int(ctx, sfp, 0);
@@ -126,7 +111,7 @@ METHOD knh__String_opSize(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST|NULLBASE] String! String.opAdd(Any v) */
 
-METHOD knh__String_opAdd(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__String_opAdd(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_cwb_t cwb = new_cwb(ctx);
 	knh_sfp_format(ctx, sfp, METHODN__s, cwb.w, KNH_NULL);
@@ -137,7 +122,7 @@ METHOD knh__String_opAdd(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[VARARGS|STATIC|NULLBASE] String! String.concat(Any v) */
 
-METHOD knh__String_concat(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__String_concat(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_sfp_t *v = sfp + 1;
 	int ac = knh_sfp_argc(ctx, v);
@@ -153,7 +138,7 @@ METHOD knh__String_concat(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] String! String.opSub(String! t) */
 
-METHOD knh__String_opSub(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__String_opSub(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_bytes_t base = knh_String_tobytes(sfp[0].s);
 	knh_bytes_t t = knh_String_tobytes(sfp[1].s);
@@ -198,7 +183,7 @@ int knh_bytes_equals_(knh_bytes_t base, size_t s, knh_bytes_t target)
 /* @method[CONST] String! String.replace(String! o, String! n)      .....  */
 /* @author nakata */
 
-METHOD knh__String_replace(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__String_replace(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_bytes_t base = knh_String_tobytes(sfp[0].s);
 	knh_bytes_t target = knh_String_tobytes(sfp[1].s);
@@ -230,7 +215,7 @@ METHOD knh__String_replace(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] String! String.opMul(Int! n) */
 
-METHOD knh__String_opMul(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__String_opMul(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_int_t n = p_int(sfp[1]);
 	if(n <= 0) {
@@ -252,7 +237,7 @@ METHOD knh__String_opMul(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[VARARGS] String! String.opFmt(Any v) */
 
-METHOD knh__String_opFmt(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__String_opFmt(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_cwb_t cwb = new_cwb(ctx);
 	knh_sfp_t *v = sfp + 1;
@@ -325,7 +310,7 @@ METHOD knh__String_opFmt(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST|NULLBASE] String! String.opDiv(String v) */
 
-METHOD knh__String_opDiv(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__String_opDiv(Ctx *ctx, knh_sfp_t *sfp)
 {
 	if(!IS_bString(sfp[0].o)) {
 		KNH_RETURN(ctx, sfp, TS_EMPTY);
@@ -351,7 +336,7 @@ METHOD knh__String_opDiv(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST|NULLBASE] String! String.opMod(String v) */
 
-METHOD knh__String_opMod(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__String_opMod(Ctx *ctx, knh_sfp_t *sfp)
 {
 	if(!IS_bString(sfp[0].o)) {
 		KNH_RETURN(ctx, sfp, TS_EMPTY);
@@ -373,7 +358,7 @@ METHOD knh__String_opMod(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] Boolean! String.opHas(String! s) */
 
-METHOD knh__String_opHas(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__String_opHas(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Boolean(ctx, sfp, knh_bytes_indexOf(knh_String_tobytes(sfp[0].s), knh_String_tobytes(sfp[1].s)) != -1);
 }
@@ -381,7 +366,7 @@ METHOD knh__String_opHas(Ctx *ctx, knh_sfp_t *sfp)
 /* ======================================================================== */
 /* @method[CONST] String! String.get(Int! n) */
 
-METHOD knh__String_get(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__String_get(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_bytes_t base = knh_String_tobytes(sfp[0].s);
 	if(knh_String_isASCII(sfp[0].s)) {
@@ -400,7 +385,7 @@ METHOD knh__String_get(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] String! String.opOffset(Int offset, Int len) */
 
-METHOD knh__String_opOffset(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__String_opOffset(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_bytes_t base = knh_String_tobytes(sfp[0].s);
 	if(knh_String_isASCII(sfp[0].s)) {
@@ -415,7 +400,6 @@ METHOD knh__String_opOffset(Ctx *ctx, knh_sfp_t *sfp)
 	}
 	else {
 		// multibytes
-		DBG2_P("hello");
 		size_t mlen = knh_bytes_mlen(base);
 		size_t offset = IS_NULL(sfp[1].o) ? 0 : knh_array_index(ctx, p_int(sfp[1]), mlen);
 		if(IS_NULL(sfp[2].o)) {
@@ -450,7 +434,7 @@ size_t bconv__toLower(Ctx *ctx, BytesConv *o, knh_bytes_t t, knh_Bytes_t *ba)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] String! String.toLower() */
 
-METHOD knh__String_toLower(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__String_toLower(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN(ctx, sfp, new_String__fbcnv(ctx, sfp[0].s, bconv__toLower, (BytesConv*)KNH_NULL));
 }
@@ -475,7 +459,7 @@ size_t bconv__toUpper(Ctx *ctx, BytesConv *o, knh_bytes_t t, knh_Bytes_t *ba)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] String! String.toUpper() */
 
-METHOD knh__String_toUpper(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__String_toUpper(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN(ctx, sfp, new_String__fbcnv(ctx, sfp[0].s, bconv__toUpper, (BytesConv*)KNH_NULL));
 }
@@ -483,7 +467,7 @@ METHOD knh__String_toUpper(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] String! String.trim() */
 
-METHOD knh__String_trim(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__String_trim(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_bytes_t t = knh_String_tobytes(sfp[0].s);
 	size_t i, s = 0;
@@ -505,7 +489,7 @@ METHOD knh__String_trim(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[CONST] String[] String.split(Any delim) */
 
-METHOD knh__String_split(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__String_split(Ctx *ctx, knh_sfp_t *sfp)
 {
 	if(IS_Regex(sfp[1].o)) {
 		KNH_RETURN(ctx, sfp, knh_Regex_split(ctx, (Regex*)sfp[1].o, sfp[0].s));
@@ -608,7 +592,7 @@ METHOD knh__String_split(Ctx *ctx, knh_sfp_t *sfp)
 
 /* @method void String.%s(OutputStream w, String m) */
 
-INLINE
+static
 void knh_String__s(Ctx *ctx, String *b, OutputStream *w, String *m)
 {
 	knh_print(ctx, w, knh_String_tobytes(b));
@@ -617,6 +601,7 @@ void knh_String__s(Ctx *ctx, String *b, OutputStream *w, String *m)
 /* ------------------------------------------------------------------------ */
 /* @method void String.%k(OutputStream w, String m) */
 
+static
 void knh_String__k(Ctx *ctx, String *o, OutputStream *w, String *m)
 {
 	int_byte_t quote = '\'';
@@ -664,7 +649,8 @@ void knh_String__k(Ctx *ctx, String *o, OutputStream *w, String *m)
 	knh_putc(ctx, w, quote);
 }
 
-/* ------------------------------------------------------------------------ */
+#endif/*KNH_CC_METHODAPI*/
+
 /* ------------------------------------------------------------------------ */
 
 #ifdef __cplusplus
