@@ -35,13 +35,15 @@
 extern "C" {
 #endif
 
+#ifdef KNH_CC_METHODAPI
+
 /* ======================================================================== */
 /* [method] */
 
 /* ------------------------------------------------------------------------ */
 /* @method[STATIC] InputStream! System.getIn() */
 
-METHOD knh__System_getIn(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__System_getIn(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN(ctx, sfp, DP(ctx->sys)->in);
 }
@@ -49,7 +51,7 @@ METHOD knh__System_getIn(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[STATIC] void System.setIn(InputStream in) */
 
-METHOD knh__System_setIn(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__System_setIn(Ctx *ctx, knh_sfp_t *sfp)
 {
 	if(knh_Context_isAdmin(ctx)) {
 		if(IS_NULL(sfp[1].o)) {
@@ -65,7 +67,7 @@ METHOD knh__System_setIn(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[STATIC] OutputStream! System.getOut() */
 
-METHOD knh__System_getOut(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__System_getOut(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN(ctx, sfp, DP(ctx->sys)->out);
 }
@@ -73,7 +75,7 @@ METHOD knh__System_getOut(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[STATIC] void System.setOut(OutputStream out) */
 
-METHOD knh__System_setOut(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__System_setOut(Ctx *ctx, knh_sfp_t *sfp)
 {
 	if(knh_Context_isAdmin(ctx)) {
 		if(IS_NULL(sfp[1].o)) {
@@ -89,7 +91,7 @@ METHOD knh__System_setOut(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[STATIC] OutputStream! System.getErr() */
 
-METHOD knh__System_getErr(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__System_getErr(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN(ctx, sfp, DP(ctx->sys)->err);
 }
@@ -97,7 +99,7 @@ METHOD knh__System_getErr(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method[STATIC] void System.setStdErr(OutputStream out) */
 
-METHOD knh__System_setErr(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__System_setErr(Ctx *ctx, knh_sfp_t *sfp)
 {
 	if(knh_Context_isAdmin(ctx)) {
 		if(IS_NULL(sfp[1].o)) {
@@ -110,18 +112,10 @@ METHOD knh__System_setErr(Ctx *ctx, knh_sfp_t *sfp)
 	KNH_RETURN_void(ctx, sfp);
 }
 
-///* ------------------------------------------------------------------------ */
-///* @method[STATIC] void System.gc() */
-//
-//METHOD knh__System_gc(Ctx *ctx, knh_sfp_t *sfp)
-//{
-//	//knh_collect(ctx);
-//}
-
 /* ------------------------------------------------------------------------ */
 /* @method[STATIC] void System.exit(Int status) */
 
-METHOD knh__System_exit(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__System_exit(Ctx *ctx, knh_sfp_t *sfp)
 {
 	knh_int_t status = IS_NULL(sfp[1].o) ? 0 : p_int(sfp[1]);
 	KNH_SECURE(ctx);
@@ -130,13 +124,10 @@ METHOD knh__System_exit(Ctx *ctx, knh_sfp_t *sfp)
 	KNH_RETURN_void(ctx, sfp);
 }
 
-/* ======================================================================== */
-/* [file] */
-
 /* ------------------------------------------------------------------------ */
 /* @method Boolean! System.hasDir(String! path) */
 
-METHOD knh__System_hasDir(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__System_hasDir(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Boolean(ctx,sfp, knh_isdir(ctx, knh_String_tobytes(sfp[1].s)));
 }
@@ -144,14 +135,214 @@ METHOD knh__System_hasDir(Ctx *ctx, knh_sfp_t *sfp)
 /* ------------------------------------------------------------------------ */
 /* @method Boolean! System.hasFile(String! path) */
 
-METHOD knh__System_hasFile(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__System_hasFile(Ctx *ctx, knh_sfp_t *sfp)
 {
 	KNH_RETURN_Boolean(ctx,sfp, knh_isfile(ctx, knh_String_tobytes(sfp[1].s)));
 }
 
+
+/* ======================================================================== */
+/* [Context] */
+
+/* ------------------------------------------------------------------------ */
+/* @method Any Context.getProperty(String! key) */
+
+Object* knh_Context_getProperty(Ctx *ctx, Context *b, knh_bytes_t key)
+{
+	Object *v = knh_DictMap_get__b(ctx,  b->props, key);
+	if(IS_NULL(v)) {
+		return knh_System_getProperty(ctx, ctx->sys, key);
+	}
+	return v;
+}
+
+/* ------------------------------------------------------------------------ */
+/* @method void Context.setProperty(String! key, Any value) */
+
+void knh_Context_setProperty(Ctx *ctx, Context *b, String *key, Any *value)
+{
+	knh_DictMap_set(ctx, b->props, key, value);
+}
+
+/* ------------------------------------------------------------------------ */
+/* @method String[]! Context.listProperties(String key) */
+
+static METHOD knh__Context_listProperties(Ctx *ctx, knh_sfp_t *sfp)
+{
+	DictSet *ds = new_DictSet(ctx, 64);
+	KNH_MOV(ctx, sfp[0].o, ds); // TO RCGC
+	if(IS_NULL(sfp[1].s)) {
+		KNH_MOV(ctx, sfp[1].o, TS_EMPTY);
+	}
+	DictMap *map = DP(ctx->sys)->props;
+	size_t i;
+	for(i = 0; i < map->size; i++) {
+		if(IS_NOTNULL(knh_DictMap_valueAt(map, i))) {
+			String *key = knh_DictMap_keyAt(map, i);
+			if(knh_String_startsWith(key, knh_String_tobytes(sfp[1].s))) {
+				knh_DictSet_add(ctx, ds, key);
+			}
+		}
+	}
+	map = ctx->props;
+	for(i = 0; i < map->size; i++) {
+		if(IS_NOTNULL(knh_DictMap_valueAt(map, i))) {
+			String *key = knh_DictMap_keyAt(map, i);
+			if(knh_String_startsWith(key, knh_String_tobytes(sfp[1].s))) {
+				knh_DictSet_add(ctx, ds, key);
+			}
+		}
+	}
+	Array *a = new_Array(ctx, CLASS_String, ds->size);
+	for(i = 0; i < ds->size; i++) {
+		knh_Array_add(ctx, a, UP(knh_DictSet_keyAt(ds, i)));
+	}
+	KNH_RETURN(ctx, sfp, a);
+}
+
+
+/* ------------------------------------------------------------------------ */
+/* @method void Context.setIn(InputStream in) */
+
+static METHOD knh__Context_setIn(Ctx *ctx, knh_sfp_t *sfp)
+{
+	KNH_ASSERT(ctx == (Ctx*)sfp[0].o);
+	if(IS_NULL(sfp[1].o)) {
+		KNH_SETv(ctx, ((Context*)ctx)->in, konoha_getClassDefaultValue(ctx, CLASS_InputStream));
+	}
+	else {
+		KNH_SETv(ctx, ((Context*)ctx)->in, sfp[1].o);
+	}
+	KNH_RETURN_void(ctx, sfp);
+}
+
+/* ------------------------------------------------------------------------ */
+/* @method void Context.setOut(OutputStream in) */
+
+static METHOD knh__Context_setOut(Ctx *ctx, knh_sfp_t *sfp)
+{
+	KNH_ASSERT(ctx == (Ctx*)sfp[0].o);
+	if(IS_NULL(sfp[1].o)) {
+		KNH_SETv(ctx, ((Context*)ctx)->out, konoha_getClassDefaultValue(ctx, CLASS_OutputStream));
+	}
+	else {
+		KNH_SETv(ctx, ((Context*)ctx)->out, sfp[1].o);
+	}
+	KNH_RETURN_void(ctx, sfp);
+}
+
+/* ------------------------------------------------------------------------ */
+/* @method void Context.setErr(OutputStream out) */
+
+static METHOD knh__Context_setErr(Ctx *ctx, knh_sfp_t *sfp)
+{
+	KNH_ASSERT(ctx == (Ctx*)sfp[0].o);
+	if(IS_NULL(sfp[1].o)) {
+		KNH_SETv(ctx, ((Context*)ctx)->err, konoha_getClassDefaultValue(ctx, CLASS_OutputStream));
+	}
+	else {
+		KNH_SETv(ctx, ((Context*)ctx)->err, sfp[1].o);
+	}
+	KNH_RETURN_void(ctx, sfp);
+}
+
 /* ======================================================================== */
 /* [movabletext] */
 
+/* @method void Context.%dump(OutputStream w, String m) */
+
+static
+void knh_Context__dump(Ctx *ctx, Context *b, OutputStream *w, String *m)
+{
+//	knh_int_t i = 0;
+//	for(i = b->esp - b->stack; i >= 0; i--) {
+//		knh_printf(ctx, w, "[%d]\t%o\n", i, b->stack[i]);
+//	}
+}
+
+/* ------------------------------------------------------------------------ */
+/* @method Exception! Exception.new(String msg, Any bag) */
+
+static METHOD knh__Exception_new(Ctx *ctx, knh_sfp_t *sfp)
+{
+	Exception *o = sfp[0].e;
+	DP(o)->eid  = EXPT_Exception;
+	DP(o)->flag = ctx->tExpt[EXPT_Exception].flag;
+
+	knh_cwb_t cwb = new_cwb(ctx);
+	knh_write__s(ctx, cwb.w, "Exception!!");
+	if(IS_NOTNULL(sfp[1].o)) {
+		knh_write__s(ctx, cwb.w, ": ");
+		knh_write(ctx, cwb.w, knh_String_tobytes(sfp[1].s));
+	}
+	KNH_SETv(ctx, DP(o)->message, new_String__cwb(ctx, cwb));
+	KNH_SETv(ctx, DP(o)->bag, sfp[2].o);
+	KNH_RETURN(ctx, sfp, o);
+}
+
+/* ------------------------------------------------------------------------ */
+/* @method Boolean! Exception.opIsa(String! m) */
+
+static METHOD knh__Exception_opIsa(Ctx *ctx, knh_sfp_t *sfp)
+{
+	KNH_RETURN_Boolean(ctx, sfp, knh_Exception_isa(ctx, sfp[0].e, sfp[1].s));
+}
+
+
+/* ------------------------------------------------------------------------ */
+/* @method void Exception.%s(OutputStream w, String m) */
+
+static
+void knh_Exception__s(Ctx *ctx, Exception *o, OutputStream *w, String *m)
+{
+	KNH_ASSERT(IS_Exception(o));
+	knh_write__s(ctx, w, EXPTN(DP(o)->eid));
+	knh_write__s(ctx, w, "!!");
+}
+
+/* ------------------------------------------------------------------------ */
+/* @method void Exception.%k(OutputStream w, String m) */
+
+static
+void knh_Exception__k(Ctx *ctx, Exception *o, OutputStream *w, String *m)
+{
+	KNH_ASSERT(IS_Exception(o));
+	knh_putc(ctx, w, '\'');
+	knh_write(ctx, w, knh_String_tobytes(DP(o)->message));
+	knh_putc(ctx, w, '\'');
+}
+
+/* ------------------------------------------------------------------------ */
+/* @method void Exception.%dump(OutputStream w, String m) */
+
+static
+void knh_Exception__dump(Ctx *ctx, Exception *o, OutputStream *w, String *m)
+{
+	KNH_ASSERT(IS_Exception(o));
+	knh_write__s(ctx, w, "---- ---- 8< 8< ---- ---- >8 >8 ---- ----");
+	knh_println(ctx, w, STEXT(""));
+	if(DP(o)->line != 0) {
+		knh_printf(ctx, w, "[%s:%d] ", DP(o)->file, DP(o)->line);
+	}
+	knh_write(ctx, w, knh_String_tobytes(DP(o)->message));
+	knh_println(ctx, w, STEXT(""));
+	if(IS_Array(DP(o)->traces)) {
+		size_t i;
+		for(i = 0; i < knh_Array_size(DP(o)->traces); i++) {
+			knh_write(ctx, w, STEXT("  at "));
+			knh_format(ctx, w, METHODN__s, knh_Array_n(DP(o)->traces, i), KNH_NULL);
+			knh_println(ctx, w, STEXT(""));
+		}
+	}
+	knh_write__s(ctx, w, "---- ---- 8< 8< ---- ---- >8 >8 ---- ----");
+	knh_println(ctx, w, STEXT(""));
+}
+
+/* ------------------------------------------------------------------------ */
+
+#else /*KNH_CC_METHODAPI*/
+
+/* ------------------------------------------------------------------------ */
 /* @method void System.%k(OutputStream w, String m) */
 
 void knh_System__k(Ctx *ctx, System *o, OutputStream *w, String *m)
@@ -198,65 +389,6 @@ void knh_System__dump(Ctx *ctx, System *o, OutputStream *w, String *m)
 	knh_write_EOL(ctx, w);
 }
 
-/* ======================================================================== */
-/* [Context] */
-
-/* ------------------------------------------------------------------------ */
-/* @method Any Context.getProperty(String! key) */
-
-Object* knh_Context_getProperty(Ctx *ctx, Context *b, knh_bytes_t key)
-{
-	Object *v = knh_DictMap_get__b(ctx,  b->props, key);
-	if(IS_NULL(v)) {
-		return knh_System_getProperty(ctx, ctx->sys, key);
-	}
-	return v;
-}
-
-/* ------------------------------------------------------------------------ */
-/* @method void Context.setProperty(String! key, Any value) */
-
-void knh_Context_setProperty(Ctx *ctx, Context *b, String *key, Any *value)
-{
-	knh_DictMap_set(ctx, b->props, key, value);
-}
-
-/* ------------------------------------------------------------------------ */
-/* @method String[]! Context.listProperties(String key) */
-
-METHOD knh__Context_listProperties(Ctx *ctx, knh_sfp_t *sfp)
-{
-	DictSet *ds = new_DictSet(ctx, 64);
-	KNH_MOV(ctx, sfp[0].o, ds); // TO RCGC
-	if(IS_NULL(sfp[1].s)) {
-		KNH_MOV(ctx, sfp[1].o, TS_EMPTY);
-	}
-	DictMap *map = DP(ctx->sys)->props;
-	size_t i;
-	for(i = 0; i < map->size; i++) {
-		if(IS_NOTNULL(knh_DictMap_valueAt(map, i))) {
-			String *key = knh_DictMap_keyAt(map, i);
-			if(knh_String_startsWith(key, knh_String_tobytes(sfp[1].s))) {
-				knh_DictSet_add(ctx, ds, key);
-			}
-		}
-	}
-	map = ctx->props;
-	for(i = 0; i < map->size; i++) {
-		if(IS_NOTNULL(knh_DictMap_valueAt(map, i))) {
-			String *key = knh_DictMap_keyAt(map, i);
-			if(knh_String_startsWith(key, knh_String_tobytes(sfp[1].s))) {
-				knh_DictSet_add(ctx, ds, key);
-			}
-		}
-	}
-	Array *a = new_Array(ctx, CLASS_String, ds->size);
-	for(i = 0; i < ds->size; i++) {
-		knh_Array_add(ctx, a, UP(knh_DictSet_keyAt(ds, i)));
-	}
-	KNH_RETURN(ctx, sfp, a);
-}
-
 /* ------------------------------------------------------------------------ */
 /* @method void Context.setEncoding(String enc) */
 
@@ -284,69 +416,8 @@ void knh_Context_setEncoding(Ctx *ctx, knh_Context_t *o, String *enc)
 }
 
 /* ------------------------------------------------------------------------ */
-/* @method void Context.setIn(InputStream in) */
 
-METHOD knh__Context_setIn(Ctx *ctx, knh_sfp_t *sfp)
-{
-	KNH_ASSERT(ctx == (Ctx*)sfp[0].o);
-	if(IS_NULL(sfp[1].o)) {
-		KNH_SETv(ctx, ((Context*)ctx)->in, konoha_getClassDefaultValue(ctx, CLASS_InputStream));
-	}
-	else {
-		KNH_SETv(ctx, ((Context*)ctx)->in, sfp[1].o);
-	}
-	KNH_RETURN_void(ctx, sfp);
-}
-
-/* ------------------------------------------------------------------------ */
-/* @method void Context.setOut(OutputStream in) */
-
-METHOD knh__Context_setOut(Ctx *ctx, knh_sfp_t *sfp)
-{
-	KNH_ASSERT(ctx == (Ctx*)sfp[0].o);
-	if(IS_NULL(sfp[1].o)) {
-		KNH_SETv(ctx, ((Context*)ctx)->out, konoha_getClassDefaultValue(ctx, CLASS_OutputStream));
-	}
-	else {
-		KNH_SETv(ctx, ((Context*)ctx)->out, sfp[1].o);
-	}
-	KNH_RETURN_void(ctx, sfp);
-}
-
-/* ------------------------------------------------------------------------ */
-/* @method void Context.setErr(OutputStream out) */
-
-METHOD knh__Context_setErr(Ctx *ctx, knh_sfp_t *sfp)
-{
-	KNH_ASSERT(ctx == (Ctx*)sfp[0].o);
-	if(IS_NULL(sfp[1].o)) {
-		KNH_SETv(ctx, ((Context*)ctx)->err, konoha_getClassDefaultValue(ctx, CLASS_OutputStream));
-	}
-	else {
-		KNH_SETv(ctx, ((Context*)ctx)->err, sfp[1].o);
-	}
-	KNH_RETURN_void(ctx, sfp);
-}
-
-/* ======================================================================== */
-/* [movabletext] */
-
-/* @method void Context.%dump(OutputStream w, String m) */
-
-void knh_Context__dump(Ctx *ctx, Context *b, OutputStream *w, String *m)
-{
-//	knh_int_t i = 0;
-//	for(i = b->esp - b->stack; i >= 0; i--) {
-//		knh_printf(ctx, w, "[%d]\t%o\n", i, b->stack[i]);
-//	}
-}
-
-/* ------------------------------------------------------------------------ */
-/* ======================================================================== */
-/* [mapping] */
-
-
-/* ------------------------------------------------------------------------ */
+#endif/*KNH_CC_METHODAPI*/
 
 #ifdef __cplusplus
 }
