@@ -43,7 +43,7 @@ extern "C" {
 
 #define _knh_Class_cid(c)     (knh_class_t)(c)->cid
 #define _KNH_FLAG_CF2OF(f)        (f)
-#define _knh_tClass_isPMZ(cid)    (ctx->tClass[cid].p1 != CLASS_Nue)
+#define _knh_Class_isGenerics(cid)    (ctx->tClass[cid].p1 != CLASS_Nue)
 
 /* ------------------------------------------------------------------------ */
 
@@ -192,6 +192,22 @@ Object *konoha_getClassDefaultValue(Ctx *ctx, knh_class_t cid)
 	return ctx->tClass[cid].fdefault(ctx, cid);
 }
 
+/* ------------------------------------------------------------------------ */
+
+#define _KNH_DEF(ctx, cid)  konoha_getClassDefaultValue(ctx, cid)
+
+Object *konoha_getDefaultValue(Ctx *ctx, knh_type_t type)
+{
+	if(IS_NNTYPE(type)) {
+		knh_class_t cid = CLASS_type(type);
+		KNH_ASSERT_cid(cid);
+		return ctx->tClass[cid].fdefault(ctx, cid);
+	}
+	else {
+		return KNH_NULL;
+	}
+}
+
 /* ======================================================================== */
 /* [PARAM] */
 
@@ -462,7 +478,7 @@ void knh_ClassMap__man(Ctx *ctx, ClassMap *o, OutputStream *w, knh_class_t cid)
 		}
 		if(from == 0) {
 			knh_write_TAB(ctx, w);
-			knh_write__class(ctx, w, cid);
+			knh_write_cid(ctx, w, cid);
 			knh_write_EOL(ctx, w);
 			from = 1;
 		}
@@ -477,7 +493,7 @@ void knh_ClassMap__man(Ctx *ctx, ClassMap *o, OutputStream *w, knh_class_t cid)
 		else {
 			knh_write__s(ctx, w, "--> ");
 		}
-		knh_write__class(ctx, w, DP(mpr)->tcid);
+		knh_write_cid(ctx, w, DP(mpr)->tcid);
 		knh_write_EOL(ctx, w);
 	}
 	if(ctx->tClass[cid].supcid != CLASS_Object) {
