@@ -83,11 +83,10 @@ Object *new_Nue(Ctx *ctx, String *msg)
 /* [Glue] */
 
 static
-void knh_fgfree__default(Ctx *ctx, knh_Glue_t *g, knh_ftraverse ftr)
+void knh_fgfree__default(Ctx *ctx, knh_Glue_t *g)
 {
-	if(IS_SWEEP(ftr)) {
-		g->ptr = NULL;
-	}
+	g->ptr = NULL;
+	g->gfree = knh_fgfree__default;
 }
 
 /* ------------------------------------------------------------------------ */
