@@ -94,11 +94,11 @@ NameSpace *knh_Context_setNameSpace(Ctx *ctx, String *nsname)
 	Asm *abr = knh_Context_getAsm(ctx);
 	if(IS_NULL(nsname)) {
 		if(IS_NameSpace(DP(abr)->ns)) {
-			KNH_SETv(ctx, DP(abr)->ns, knh_Runtime_getNameSpace(ctx, knh_String_tobytes(TS_main)));
+			KNH_SETv(ctx, DP(abr)->ns, knh_System_getNameSpace(ctx, knh_String_tobytes(TS_main)));
 		}
 	}
 	else {
-		KNH_SETv(ctx, DP(abr)->ns, knh_Runtime_getNameSpace(ctx, knh_String_tobytes(nsname)));
+		KNH_SETv(ctx, DP(abr)->ns, knh_System_getNameSpace(ctx, knh_String_tobytes(nsname)));
 	}
 	return DP(abr)->ns;
 }
