@@ -36,7 +36,38 @@ extern "C" {
 #endif
 
 /* ======================================================================== */
-/* [CLASS_DECL] */
+/* [CLASS] */
+
+/* ------------------------------------------------------------------------ */
+/* [META] */
+
+static
+knh_flag_t knh_StmtCLASS_flag(Ctx *ctx, Stmt *o)
+{
+	knh_flag_t flag = 0;
+	if(IS_DictMap(DP(o)->metaDictMap)) {
+		Object *v = knh_DictMap_get__b(ctx, DP(o)->metaDictMap, STEXT("Final"));
+		if(IS_NOTNULL(v)) {
+			flag |= KNH_FLAG_CF_FINAL;
+		}
+		v = knh_DictMap_get__b(ctx, DP(o)->metaDictMap, STEXT("Private"));
+		if(IS_NOTNULL(v)) {
+			flag |= KNH_FLAG_CF_PRIVATE;
+		}
+		v = knh_DictMap_get__b(ctx, DP(o)->metaDictMap, STEXT("Interface"));
+		if(IS_NOTNULL(v)) {
+			flag |= KNH_FLAG_CF_INTERFACE;
+		}
+		v = knh_DictMap_get__b(ctx, DP(o)->metaDictMap, STEXT("Singleton"));
+		if(IS_NOTNULL(v)) {
+			flag |= KNH_FLAG_CF_SINGLETON;
+		}
+	}
+	return flag;
+}
+
+/* ------------------------------------------------------------------------ */
+/* [implements] */
 
 static
 Mapper* new_Mapper__interface(Ctx *ctx, knh_class_t scid, knh_class_t tcid)
@@ -106,13 +137,13 @@ void knh_class_addInterface(Ctx *ctx, knh_class_t cid, knh_class_t icid)
 	}
 }
 
-/* ------------------------------------------------------------------------ */
-
-static
-Object *knh_tClass_fdefault__OBJECT(Ctx *ctx, knh_class_t cid)
-{
-	return new_Object_init(ctx, ctx->tClass[cid].oflag, cid, 0);
-}
+///* ------------------------------------------------------------------------ */
+//
+//static
+//Object *knh_tClass_fdefault__OBJECT(Ctx *ctx, knh_class_t cid)
+//{
+//	return new_Object_init(ctx, ctx->tClass[cid].oflag, cid, 0);
+//}
 
 /* ------------------------------------------------------------------------ */
 
@@ -120,102 +151,82 @@ static
 int knh_StmtCLASS_decl(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 {
 	char bufn[CLASSNAME_BUFSIZ];
-	knh_snprintf(bufn, sizeof(bufn), "%s.%s", knh_String_tochar(DP(ns)->nsname),
-			sToken(StmtCLASS_class(stmt)));
-	{
-		knh_tClass_t *TC = NULL;
-		knh_class_t cid  = knh_NameSpace_getClass(ctx, ns, B(bufn));
-		knh_class_t supcid = CLASS_unknown, oldcid = CLASS_Object;
-		if(SP(StmtCLASS_superclass(stmt))->tt == TT_ASIS) {
+	knh_snprintf(bufn, sizeof(bufn), "%s.%s", knh_String_tochar(DP(ns)->nsname), sToken(StmtCLASS_class(stmt)));
+
+	knh_class_t cid  = knh_NameSpace_getClass(ctx, ns, B(bufn));
+	if(cid == CLASS_unknown) {
+		cid = knh_tClass_newId(ctx);
+		KNH_ASSERT(ctx->tClass[cid].class_cid == NULL);
+	}
+	else {
+		knh_Asm_perror(ctx, abr, KMSG_EOVERRIDE, CLASSN(cid));
+		knh_Stmt_done(ctx, stmt);
+		return 0;
+	}
+
+	knh_class_t supcid = CLASS_Object;
+	if(SP(StmtCLASS_superclass(stmt))->tt != TT_ASIS) {
+		supcid = CLASS_Object;
+	}
+	else {
+		supcid = knh_NameSpace_getClass(ctx, ns, knh_Token_tobytes(ctx, StmtCLASS_superclass(stmt)));
+		if(supcid == CLASS_unknown) {
+			knh_Asm_perror(ctx, abr, KMSG_UCLASSN, NULL);
 			supcid = CLASS_Object;
+			knh_Token_perrata(ctx, StmtCLASS_superclass(stmt), CLASSN(supcid));
 		}
-		else {
-			supcid = knh_NameSpace_getClass(ctx, ns, knh_Token_tobytes(ctx, StmtCLASS_superclass(stmt)));
-			if(supcid == CLASS_unknown && cid == CLASS_unknown) {
-				knh_Asm_perror(ctx, abr, KMSG_UCLASSN, NULL);
-				supcid = CLASS_Object;
-				knh_Token_perrata(ctx, StmtCLASS_superclass(stmt), CLASSN(supcid));
-			}
-			if(supcid != CLASS_unknown) {
-				if(knh_class_isFinal(supcid)) {
-					knh_Asm_perror(ctx, abr, KMSG_EEXTENDS, CLASSN(supcid));
-					knh_Stmt_done(ctx, stmt);
-					return 0;
-				}
-			}
-		}
-		if(cid == CLASS_unknown) {
-			cid = knh_tClass_newId(ctx);
-			KNH_ASSERT(ctx->tClass[cid].class_cid == NULL);
-		}
-		else {
-			DEBUG3("redefine %s", CLASSN(cid));
-			KNH_ASSERT_cid(cid);
-			if(ctx->tClass[cid].bcid != CLASS_Object) {
-				knh_Asm_perror(ctx, abr, KMSG_EOVERRIDE, CLASSN(cid));
-				knh_Stmt_done(ctx, stmt);
-				return 0;
-			}
-			if(!knh_StmtMETA_isOverride(ctx, stmt)) {
-				knh_Asm_perror(ctx, abr, KMSG_AOVERRIDE, CLASSN(cid));
-				knh_Stmt_done(ctx, stmt);
-				return 0;
-			}
-			if(ctx->tClass[cid].supcid != supcid) {
-				knh_Asm_perror(ctx, abr, KMSG_DIFFCLASSN, NULL);
-				supcid = ctx->tClass[cid].supcid;
-				knh_Token_perrata(ctx, StmtCLASS_superclass(stmt), CLASSN(supcid));
-			}
-			oldcid = cid;
-			cid = knh_tClass_newId(ctx);
-			KNH_ASSERT(ctx->tClass[cid].class_cid == NULL);
+		else if(knh_class_isFinal(supcid)) {
+			knh_Asm_perror(ctx, abr, KMSG_EEXTENDS, CLASSN(supcid));
+			knh_Stmt_done(ctx, stmt);
+			return 0;
 		}
+	}
 
-		DP(StmtCLASS_class(stmt))->cid = cid;
-		TC = (knh_tClass_t*)&(ctx->tClass[cid]);
-		TC->cflag  = knh_StmtCLASS_flag(ctx, stmt);
-		TC->oflag  = KNH_FLAG_CF2OF(TC->cflag);
+	DP(StmtCLASS_class(stmt))->cid = cid;
 
+	knh_tClass_t *TC = (knh_tClass_t*)&(ctx->tClass[cid]);
+	TC->cflag  = knh_StmtCLASS_flag(ctx, stmt);
+	TC->oflag  = KNH_FLAG_CF2OF(TC->cflag);
+	if(SP(StmtCLASS_instmt(stmt))->stt == STT_DONE) {
+		TC->bcid   = CLASS_Any;
+	}
+	else {
 		TC->bcid   = CLASS_Object;
-		TC->supcid = supcid;
-		if(supcid == CLASS_Object) {
-			TC->offset = 0;
-		}else {
-			KNH_ASSERT(supcid < cid);
-			TC->offset = ctx->tClass[supcid].bsize;
-		}
+	}
+	TC->supcid = supcid;
+	if(supcid == CLASS_Object) {
+		TC->offset = 0;
+	}else {
+		KNH_ASSERT(supcid < cid);
+		TC->offset = ctx->tClass[supcid].bsize;
+	}
+	KNH_ASSERT(TC->class_cid == NULL);
+	konoha_setClassName(ctx, cid, new_String(ctx, B(bufn), NULL));
+	KNH_INITv(TC->cstruct, new_ClassStruct0(ctx, 0, 8));
+	KNH_INITv(TC->cmap, ctx->tClass[CLASS_Any].cmap);
+	konoha_setClassDefaultValue(ctx, cid, KNH_NULL, NULL);
+	knh_NameSpace_setLocalName(ctx, ns, cid);
 
-		KNH_ASSERT(TC->class_cid == NULL);
-		konoha_setClassName(ctx, cid, new_String(ctx, B(bufn), NULL));
-		KNH_INITv(TC->cstruct, new_ClassStruct0(ctx, 0, 8));
-		KNH_INITv(TC->cmap, new_ClassMap0(ctx, 0));
-		KNH_INITv(TC->cspec, KNH_NULL);
-		knh_NameSpace_setLocalName(ctx, ns, cid);
-
-		if(oldcid != CLASS_Object) {
-			knh_class_addInterface(ctx, cid, oldcid);
-		}
-		TC->fdefault = knh_tClass_fdefault__OBJECT;
-		/* implements */ {
-			Stmt *istmt = StmtCLASS_interface(stmt);
-			if(SP(istmt)->stt != STT_DONE) {
-				int i, n = DP(istmt)->size;
-				for(i = 0; i < n; i++) {
-					Token *tk = DP(stmt)->tokens[i];
-					knh_class_t icid = knh_NameSpace_getClass(ctx, ns, knh_Token_tobytes(ctx, tk));
-					if(icid == CLASS_unknown) {
-						knh_Token_perror(ctx, tk, KMSG_UCLASSN);
-						continue;
-					}
-					if(!knh_class_isInterface(icid)) {
-						knh_Token_perror(ctx, tk, KMSG_EIMPLEMENTS);
-						continue;
-					}
-					knh_class_addInterface(ctx, cid, icid);
-				}
+	if(SP(StmtCLASS_interface(stmt))->stt != STT_DONE) {
+		Stmt *istmt = StmtCLASS_interface(stmt);
+		int i, n = DP(istmt)->size;
+		for(i = 0; i < n; i++) {
+			Token *tk = DP(stmt)->tokens[i];
+			knh_class_t icid = knh_NameSpace_getClass(ctx, ns, knh_Token_tobytes(ctx, tk));
+			if(icid == CLASS_unknown) {
+				knh_Token_perror(ctx, tk, KMSG_UCLASSN);
+				continue;
 			}
+			if(!knh_class_isInterface(icid)) {
+				knh_Token_perror(ctx, tk, KMSG_EIMPLEMENTS);
+				continue;
+			}
+			knh_class_addInterface(ctx, cid, icid);
 		}
 	}
+	if(SP(StmtCLASS_instmt(stmt))->stt == STT_DONE) {
+		knh_Stmt_done(ctx, stmt);
+	}
 	return 1;
 }
 
@@ -227,7 +238,8 @@ int knh_StmtIMPORT_decl(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 {
 	String *fname = (String*)DP(StmtIMPORT_file(stmt))->data;
 	char bufp[FILENAME_BUFSIZ], buff[FILENAME_BUFSIZ];
-	String *cfname = knh_tfileid_name(ctx, SP(stmt)->fileid);
+
+	String *cfname = konoha_getFileName(ctx, SP(stmt)->fileid);
 	KNH_ASSERT(IS_String(fname));
 	if(knh_String_endsWith(cfname, STEXT(".k"))) {
 		knh_format_parentpath(bufp, sizeof(bufp), knh_String_tobytes(cfname), 1);
@@ -236,25 +248,8 @@ int knh_StmtIMPORT_decl(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 		bufp[0]=0;
 	}
 	knh_format_catpath(buff, sizeof(buff), B(bufp), knh_String_tobytes(fname));
-	if(!knh_isfile(ctx, B(buff))) {
-		knh_Asm_perror(ctx, abr, KMSG_UPATH, buff);
-		return 0;
-	}
-	knh_fileid_t fileid = knh_tName_getFileId(ctx, B(buff));
-	if(!knh_NameSpace_isLoaded(ctx, ns, fileid)) {
-		knh_NameSpace_loaded(ctx, ns, fileid);
-		InputStream *in = new_FileInputStream(ctx, B(buff));
-		if(knh_InputStream_isClosed(in)) {
-			knh_Asm_perror(ctx, abr, KMSG_UPATH, buff);
-			return 0;
-		}
-		DP(in)->fileid = fileid;
-		knh_InputStream_setEncoding(ctx, in, knh_systemEncoding);
-		konohac_eval(ctx, DP(ns)->nsname, in);
-	}
-	else {
-		DEBUG3("already imported %s", buff);
-	}
+
+	knh_NameSpace_load(ctx, ns, B(buff), 1 /* isEval */);
 	return 1;
 }
 
@@ -266,8 +261,8 @@ int knh_StmtUIMPORT_decl(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 	Token *tk = DP(stmt)->tokens[0];
 	knh_bytes_t name = knh_Token_tobytes(ctx, tk);
 	knh_index_t loc = knh_bytes_rindex(name, '.');
-	if(loc != -1) {
-		if(knh_System_using(ctx, knh_bytes_first(name, loc))) {
+	if(loc != -1) { /* using Math.sin */
+		if(knh_System_loadPackage(ctx, knh_bytes_first(name, loc))) {
 			knh_class_t newcid = knh_NameSpace_getClass(ctx, knh_rootNameSpace, name);
 			if(newcid == CLASS_unknown) {
 				knh_Token_perror(ctx, tk, KMSG_UCLASSN);
@@ -281,7 +276,7 @@ int knh_StmtUIMPORT_decl(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 			return 1;
 		}
 	}else {
-		if(knh_System_using(ctx, name)) {
+		if(knh_System_loadPackage(ctx, name)) {
 			if(knh_Token_isTailWildCard(tk)) {
 				knh_NameSpace_import(ctx, ns, name);
 			}
@@ -340,7 +335,7 @@ int knh_StmtXCLASS_decl(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns, knh_class
 
 	char bufcu[CLASSNAME_BUFSIZ];
 	knh_format_classurn(ctx, bufcu, sizeof(bufcu), bcid, knh_Token_tobytes(ctx, tkurn));
-	knh_class_t cid = knh_tClass_findcid(ctx, B(bufcu));
+	knh_class_t cid = konoha_findcid(ctx, B(bufcu));
 	if(cid == bcid || cid == CLASS_unknown) {
 		knh_Token_perror(ctx, tkurn, KMSG_UPATH);
 		cid = bcid;
@@ -529,14 +524,13 @@ int knh_Stmt_eval(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns, int isEval)
 
 /* ------------------------------------------------------------------------ */
 
-int
-konohac_compile(Ctx *ctx, String *nsname, Stmt *stmt_head, int isEval)
+int knh_Stmt_complie(Ctx *ctx, Stmt *stmt, String *nsname, int isEval)
 {
 	Asm *abr = knh_Context_getAsm(ctx);
 	NameSpace *ns = knh_Context_setNameSpace(ctx, nsname);
-	Stmt *cur = stmt_head;
+	Stmt *cur = stmt;
 
-	DP(abr)->fileid = SP(stmt_head)->fileid;
+	DP(abr)->fileid = SP(stmt)->fileid;
 	while(IS_Stmt(cur)) {
 		knh_stmt_t stt = SP(cur)->stt;
 		DP(abr)->line = SP(cur)->line;
@@ -585,7 +579,7 @@ konohac_compile(Ctx *ctx, String *nsname, Stmt *stmt_head, int isEval)
 		cur = DP(cur)->next;
 	}
 
-	cur = stmt_head;
+	cur = stmt;
 	while(IS_Stmt(cur)) {
 		knh_stmt_t stt = SP(cur)->stt;
 		DP(abr)->line = SP(cur)->line;
@@ -616,7 +610,7 @@ konohac_compile(Ctx *ctx, String *nsname, Stmt *stmt_head, int isEval)
 		cur = DP(cur)->next;
 	}
 
-	cur = stmt_head;
+	cur = stmt;
 	while(IS_Stmt(cur)) {
 		knh_stmt_t stt = SP(cur)->stt;
 		KNH_ASM_SETLINE(ctx, abr, SP(cur)->line);
@@ -645,7 +639,7 @@ konohac_compile(Ctx *ctx, String *nsname, Stmt *stmt_head, int isEval)
 /* [main] */
 
 static
-Stmt *konohac_parse(Ctx *ctx, InputStream *in)
+Stmt *knh_InputStream_parseStmt(Ctx *ctx, InputStream *in)
 {
 	Token *tk = new_Token(ctx, 0, DP(in)->fileid, 0, knh_char_totoken('{'));
 	KNH_LPUSH(ctx, tk);
@@ -656,6 +650,22 @@ Stmt *konohac_parse(Ctx *ctx, InputStream *in)
 	return stmt;
 }
 
+
+/* ------------------------------------------------------------------------ */
+
+Stmt *knh_bytes_parseStmt(Ctx *ctx, knh_bytes_t kscript)
+{
+	knh_cwb_t cwb = new_cwb(ctx);
+	knh_Bytes_write(ctx, cwb.ba, kscript);
+	knh_Bytes_putc(ctx, cwb.ba, ';');
+	InputStream *in = new_BytesInputStream(ctx, cwb.ba, cwb.pos, knh_Bytes_size(cwb.ba));
+	DP(in)->fileid = 0;
+	DP(in)->line = 0;
+	Stmt *stmt = knh_InputStream_parseStmt(ctx, in);
+	knh_cwb_clear(cwb);
+	return stmt;
+}
+
 /* ------------------------------------------------------------------------ */
 
 void konohac_eval(Ctx *ctx, String *nsname, InputStream *in)
@@ -664,10 +674,10 @@ void konohac_eval(Ctx *ctx, String *nsname, InputStream *in)
 	KNH_LPUSH(ctx, new_ExceptionHandler(ctx));
 	KNH_TRY(ctx, L_CATCH, lsfp, 0);
 	{
-		Stmt *stmt = konohac_parse(ctx, in);
+		Stmt *stmt = knh_InputStream_parseStmt(ctx, in);
 		KNH_LPUSH(ctx, stmt);
 		DBG2_DUMP(ctx, stmt, KNH_NULL, "stmt");
-		konohac_compile(ctx, nsname, stmt, !knh_Context_isCompiling(ctx) /* isrun 1 */);
+		knh_Stmt_complie(ctx, stmt, nsname, !knh_Context_isCompiling(ctx) /* isrun 1 */);
 	}
 	KNH_LOCALBACK(ctx, lsfp);
 	return;
@@ -680,17 +690,107 @@ void konohac_eval(Ctx *ctx, String *nsname, InputStream *in)
 
 /* ------------------------------------------------------------------------ */
 
-Stmt *konoha_parse(Ctx *ctx, char *kscript)
+void knh_Asm_openlib(Ctx *ctx, Asm *abr, knh_bytes_t fpath)
 {
 	knh_cwb_t cwb = new_cwb(ctx);
-	knh_Bytes_write(ctx, cwb.ba, B(kscript));
-	knh_Bytes_putc(ctx, cwb.ba, ';');
-	InputStream *in = new_BytesInputStream(ctx, cwb.ba, cwb.pos, knh_Bytes_size(cwb.ba));
-	DP(in)->fileid = 0;
-	DP(in)->line = 0;
-	Stmt *stmt = konohac_parse(ctx, in);
+	knh_index_t idx = knh_bytes_rindex(fpath, '.');
+	if(idx > 0) fpath.len = idx;
+	knh_Bytes_write(ctx, cwb.ba, fpath);
+	knh_Bytes_write(ctx, cwb.ba, STEXT(KONOHA_OS_DLLEXT));
+	knh_Bytes_putc(ctx, cwb.ba, 0);
+
+	if(DP(abr)->dlhdr != NULL) {
+		//knh_dlclose(ctx, DP(abr)->dlhdr);
+		DP(abr)->dlhdr = NULL;
+	}
+
+	knh_bytes_t f = knh_cwb_tobytes(cwb);
+	DBG2_P("opening lib .. '%s'", f.buf);
+	DP(abr)->dlhdr =knh_dlopen(ctx, (char*)f.buf, KNH_RTLD_LAZY);
+	if(DP(abr)->dlhdr != NULL) {
+		knh_finit finit = (knh_finit)knh_dlsym(ctx, DP(abr)->dlhdr, "init");
+		if(finit != NULL) {
+			finit(ctx);
+		}
+	}
+	else {
+		DBG2_P("cannot openlib .. '%s'", f.buf);
+	}
 	knh_cwb_clear(cwb);
-	return stmt;
+}
+
+
+/* ======================================================================== */
+/* [loaded] */
+
+static
+void knh_NameSpace_loaded(Ctx *ctx, NameSpace *o, knh_fileid_t fileid)
+{
+	KNH_ASSERT(IS_NameSpace(o));
+	if(IS_NULL(DP(o)->lconstDictMap)) {
+		KNH_SETv(ctx, DP(o)->lconstDictMap, new_DictMap0(ctx, 16));
+	}
+	char buf[40];
+	knh_snprintf(buf, sizeof(buf), "_LOADED_%d", (int)fileid);
+	knh_DictMap_set(ctx, DP(o)->lconstDictMap, new_String(ctx, B(buf), NULL), UP(konoha_getFileName(ctx, fileid)));
+}
+
+/* ------------------------------------------------------------------------ */
+
+static
+int knh_NameSpace_isLoaded(Ctx *ctx, NameSpace *o, knh_fileid_t fileid)
+{
+	if(IS_NOTNULL(DP(o)->lconstDictMap)) {
+		char buf[40];
+		knh_snprintf(buf, sizeof(buf), "_LOADED_%d", (int)fileid);
+		return (knh_DictMap_index__b(DP(o)->lconstDictMap, B(buf)) != -1);
+	}
+	return 0;
+}
+
+/* ------------------------------------------------------------------------ */
+
+int knh_NameSpace_load(Ctx *ctx, NameSpace *ns, knh_bytes_t fpath, int isEval)
+{
+	knh_fileid_t fileid = konoha_getFileId(ctx, fpath);
+	if(knh_NameSpace_isLoaded(ctx, ns, fileid)) {
+		DBG2_P("Already imported: %s", fpath.buf);
+		return 1;
+	}
+	knh_NameSpace_loaded(ctx, ns, fileid);
+	knh_sfp_t *lsfp = KNH_LOCAL(ctx);
+	InputStream *in = new_FileInputStream(ctx, fpath);
+	KNH_LPUSH(ctx, in);
+	DP(in)->fileid = fileid;
+	knh_InputStream_setEncoding(ctx, in, knh_systemEncoding);
+	Stmt *stmt = knh_InputStream_parseStmt(ctx, in);
+	KNH_LPUSH(ctx, stmt);
+	if(isEval) {
+		knh_Asm_openlib(ctx, knh_Context_getAsm(ctx), fpath);
+	}
+	knh_Stmt_complie(ctx, stmt, DP(ns)->nsname, isEval);
+	KNH_LOCALBACK(ctx, lsfp);
+	return 1;
+}
+
+/* ------------------------------------------------------------------------ */
+
+void konoha_compile(Ctx *ctx, String *nsname, knh_bytes_t fpath)
+{
+	knh_sfp_t *lsfp = KNH_LOCAL(ctx);
+	KNH_LPUSH(ctx, new_ExceptionHandler(ctx));
+	KNH_TRY(ctx, L_CATCH, lsfp, 0);
+	{
+		NameSpace *ns = knh_Context_setNameSpace(ctx, nsname);
+		knh_NameSpace_load(ctx, ns, fpath, 0);
+	}
+	KNH_LOCALBACK(ctx, lsfp);
+	return;
+
+	/* catch */
+	L_CATCH:;
+	KNH_PRINT_STACKTRACE(ctx, lsfp, 0);
+	return;
 }
 
 /* ------------------------------------------------------------------------ */
