@@ -1438,7 +1438,7 @@ Stmt *new_StmtCAST(Ctx *ctx, Token *tk_cast, knh_tokens_t *tc)
 
 /* ------------------------------------------------------------------------ */
 
-static int knh_Token_isNEW(Ctx *ctx, Token *tk)
+int knh_Token_isNEW(Ctx *ctx, Token *tk)
 {
 	char *p = sToken(tk);
 	return (p[0]=='n' && p[1] == 'e' && p[2] == 'w' && (p[3]==0 || p[3]==':'));
@@ -1721,6 +1721,7 @@ static Term *new_TermEXPR(Ctx *ctx, knh_tokens_t *tc, int lr)
 	L_PARAM:;
 	KNH_ASSERT(stmt != NULL);
 	KNH_ASSERT(pc > 0);
+	//DBG2_P("oc=%d, fc=%d, pc=%d %s", oc, fc, pc, knh_token_tochar(SP(ts[pc])->tt));
 	KNH_ASSERT(SP(ts[pc])->tt == TT_PARENTHESIS);
 	{
 		knh_tokens_t ptc;
