@@ -84,7 +84,7 @@ Mapper *knh_tmapper_getcache(Ctx *ctx, knh_class_t scid, knh_class_t tcid)
 	}
 	return mar;
 #else
-	return (Mapper*)knh_Hash_get__hcode(ctx, (knh_Hash_t*)mprHashMap(ctx), hcode);
+	return (Mapper*)knh_HashMap_get__hcode(ctx, mprHashMap(ctx), hcode);
 #endif
 }
 
@@ -157,6 +157,7 @@ Mapper *knh_tMapper_find_(Ctx *ctx, knh_class_t scid, knh_class_t tcid, int isge
 	KNH_ASSERT_cid(tcid);
 	DBG2_P("finding.. %s ==> %s",CLASSN(scid), CLASSN(tcid));
 	KNH_ASSERT(scid != CLASS_Any); KNH_ASSERT(tcid != CLASS_Nue);
+	//KNH_ABORT();
 
 	Mapper *mpr = knh_tmapper_getcache(ctx, scid, tcid);
 	if(IS_NOTNULL(mpr)) { return mpr; }
