@@ -228,7 +228,10 @@ void knh_Any_init(Ctx *ctx, knh_Glue_t *g, int init)
 static
 void knh_Any_traverse(Ctx *ctx, knh_Glue_t *g, knh_ftraverse ftr)
 {
-	g->gfree(ctx, g, ftr);
+	if(IS_SWEEP(ftr)) {
+		g->gfree(ctx, g);
+		knh_Glue_init(ctx, g, NULL, NULL);
+	}
 }
 
 /* ======================================================================== */
