@@ -286,19 +286,6 @@ void knh_Exception_addStackTrace(Ctx *ctx, Exception *o, String *msg)
 //	}
 //}
 
-/* ------------------------------------------------------------------------ */
-
-KNHAPI(char*) konoha_doing(Ctx *ctx, char *msg)
-{
-	char *oldmsg = ctx->doing;
-	((Context*)ctx)->doing = msg;
-	return oldmsg;
-}
-
-/* ------------------------------------------------------------------------ */
-
-
-
 /* ------------------------------------------------------------------------ */
 
 static
