@@ -571,11 +571,16 @@ char *knh_format_pscript(Ctx *ctx, char *buf, size_t bufsiz, knh_bytes_t pkgname
 	knh_snprintf(buf, bufsiz, "%s/package/%s/%s.k", knh_String_tochar(knh_homeDir), pbuf, pbuf);
 #endif
 	if(knh_isfile(ctx, B(buf))) return buf;
+	p = knh_getenv("HOME");
+	if(p != NULL) {
+		knh_snprintf(buf, bufsiz, "%s/.konoha/%s/%s.k", p, pbuf, pbuf);
+		if(knh_isfile(ctx, B(buf))) return buf;
+	}
 	if(ctx->cwd == NULL) {
-		knh_snprintf(buf, bufsiz, "./.package/%s/%s.k", pbuf, pbuf);
+		knh_snprintf(buf, bufsiz, "./.konoha/%s/%s.k", pbuf, pbuf);
 	}
 	else {
-		knh_snprintf(buf, bufsiz, "%s/.package/%s/%s.k", ctx->cwd, pbuf, pbuf);
+		knh_snprintf(buf, bufsiz, "%s/.konoha/%s/%s.k", ctx->cwd, pbuf, pbuf);
 	}
 	if(knh_isfile(ctx, B(buf))) return buf;
 	return NULL;
